==> siag_3.1.22.orig.tar.gz: siag-3.1.22/xcommon/xcommon-ad.h <==
APPNAME "*beNiceToColormap:		False",
APPNAME "*background:			grey",
APPNAME "*foreground:			black",
APPNAME "*font:				-*-helvetica-medium-r-*-12-*",
APPNAME "*Combo*borderWidth:		0",
APPNAME "*Combo*height:			18",
APPNAME "*Command.shadowWidth:		1",
APPNAME "*Command.translations:	#override			\\n\
	<Enter>:			siag-highlight()		\\n\
	<Leave>:			siag-unhighlight()",
APPNAME "*Frame.shadowType:		Raised",
APPNAME "*Frame.allowResize:		False",
APPNAME "*Label*borderWidth:		0",
APPNAME "*Label*shadowWidth:		0",
APPNAME "*Label*justify:		Left",
APPNAME "*Label*topShadowContrast:	-40",
APPNAME "*Label*bottomShadowContrast:	-20",
APPNAME "*List*borderWidth:		1",
APPNAME "*List*defaultColumns:		1",
APPNAME "*List*forceColumns:		True",
APPNAME "*topbox*List*background:	white",
#if 0
APPNAME "*MenuButton.shadowWidth:	1",
#else
APPNAME "*MenuButton.shadowWidth:	0",
APPNAME "*SiagMenuButton.shadowWidth:	0",
#endif
APPNAME "*SiagMenuButton.translations:	#override			\\n\
	<Enter>:		siag-highlight()		\\n\
	<Leave>:		siag-unhighlight()",
APPNAME "*menubox.SiagMenuButton.translations:	#override			\\n\
	<Enter>:		siag-highlight(1)		\\n\
	<Leave>:		siag-unhighlight(0)",
APPNAME "*MenuButton.translations:	#override			\\n\
	<Enter>:		siag-highlight()		\\n\
	<Leave>:		siag-unhighlight()",
APPNAME "*menubox.MenuButton.translations:	#override			\\n\
	<Enter>:		siag-highlight(1)		\\n\
	<Leave>:		siag-unhighlight(0)",
APPNAME "*SmeBSB.rightMargin:	10",
APPNAME "*Repeater.shadowWidth:		1",
APPNAME "*Repeater.translations:	#override			\\n\
	<Enter>:			siag-highlight()		\\n\
	<Leave>:			siag-unhighlight()",
APPNAME "*Scrollbar*borderWidth:	0",
APPNAME "*SimpleMenu*font:		-*-helvetica-medium-r-*-10-*",
APPNAME "*SimpleMenu.translations:	#override		\\n\
	:<EnterWindow>:		highlight()	\\n\
	:<LeaveWindow>:		unhighlight()			\\n\
	:<Motion>:		highlight() menu-motion()	\\n\
	:<BtnUp>:		MenuPopdown() notify() unhighlight()",
APPNAME "*Text*font:			-*-helvetica-medium-r-*-12-*",
APPNAME "*Text*background:		white",
APPNAME "*Text*Scrollbar.background:	grey",
APPNAME "*TextField*font:			-*-helvetica-medium-r-*-12-*",
APPNAME "*TextField*background:		white",
APPNAME "*TextField*height:		20",
APPNAME "*Toggle.shadowWidth:		1",
APPNAME "*Toggle.translations:	#override			\\n\
	<Enter>:		siag-highlight(2 1)		\\n\
	<Leave>:		siag-unhighlight(1 1)",
APPNAME "*Viewport*allowHoriz:		True",
APPNAME "*Viewport*allowVert:		True",
APPNAME "*Viewport*useBottom:		True",
APPNAME "*Viewport*useRight:		True",

APPNAME "*tooltip_label.background:	LightYellow",
APPNAME "*tooltip_label.font:	-*-helvetica-medium-r-*-10-*",

APPNAME "*Tooltip.Label.background:	LightYellow",
APPNAME "*Tooltip.Label.font:	-*-helvetica-medium-r-*-10-*",

==> siag_3.5.1.orig.tar.gz: siag-3.5.1/xcommon/xcommon-ad.h <==
APPNAME "*beNiceToColormap:		False",

/* This is to avoid getting black borders from XawM */
"*highlightThickness:			0",

"*background:			grey",
"*foreground:			black",
"*font:				-*-helvetica-medium-r-*-12-*",
#if 0
APPNAME "*Combo*borderWidth:		0",
APPNAME "*Combo*height:			18",
#endif
APPNAME "*Command.shadowWidth:		1",
APPNAME "*Command.translations:	#override			\\n\
	<Enter>:			siag-highlight()		\\n\
	<Leave>:			siag-unhighlight()",
APPNAME "*MwFrame.shadowType:		Raised",
APPNAME "*MwFrame.allowResize:		False",
APPNAME "*Label*borderWidth:		0",
APPNAME "*Label*shadowWidth:		0",
APPNAME "*Label*justify:		Left",
APPNAME "*Label*topShadowContrast:	-40",
APPNAME "*Label*bottomShadowContrast:	-20",
APPNAME "*List*borderWidth:		1",
APPNAME "*List*defaultColumns:		1",
APPNAME "*List*forceColumns:		True",
APPNAME "*topbox*List*background:	white",
APPNAME "*Repeater.shadowWidth:		1",
/*APPNAME*/ "*Repeater.translations:	#override			\\n\
	<Enter>:			siag-highlight()		\\n\
	<Leave>:			siag-unhighlight()",
APPNAME "*Scrollbar*borderWidth:	0",
APPNAME "*Text*background:		white",
APPNAME "*Text*Scrollbar.background:	grey",
APPNAME "*MwTextField*background:		white",
APPNAME "*MwTextField*height:		20",
APPNAME "*Toggle.shadowWidth:		1",
/*APPNAME*/ "*Toggle.translations:	#override			\\n\
	<Enter>:		siag-highlight(2 1)		\\n\
	<Leave>:		siag-unhighlight(1 1)",
APPNAME "*Viewport*allowHoriz:		True",
APPNAME "*Viewport*allowVert:		True",
APPNAME "*Viewport*useBottom:		True",
APPNAME "*Viewport*useRight:		True",

APPNAME "*tooltip_label.background:	LightYellow",

APPNAME "*MwTooltip.Label.background:	LightYellow",

APPNAME "*btnHelp.gravitation:		right",
